/* ISC license. */

/* Generated by: ./configure --prefix=/usr --sysconfdir=/etc --libexecdir=/usr/lib --disable-allstatic --disable-static --enable-pkgconfig --enable-shared --with-pkgconfig */

#ifndef S6_CONFIG_H
#define S6_CONFIG_H

#define S6_VERSION "2.15.0.0"
#define S6_BINPREFIX ""
#define S6_EXTBINPREFIX ""
#define S6_EXTLIBEXECPREFIX "/usr/lib/"
#define S6_LIBEXECPREFIX "/usr/lib/"
#define S6_SYSCONFPREFIX "/etc/"
#undef S6_USE_EXECLINE
#define S6_USE_EXECLINE
#undef S6_WRAP_DAEMONTOOLS
#undef S6_WRAP_RUNIT

#endif
